#!/usr/bin/env python
# -*- coding: utf-8 -*-


def _render(html):
    return '''
render: () -> """
%s
"""
'''.lstrip().rstrip() % html.lstrip().rstrip()


def _style(css):
    return '''
style: """
%s
"""
'''.lstrip().rstrip() % css.lstrip().rstrip()


def _update(value):
    return """update: (output, domEl) ->
    %s
""" % value.lstrip().rstrip()


class Coffee:
    """index.coffee generator class"""
    __readme__ = ["command", "refresh", "html", "update", "style"]
    command = "echo"
    refresh = '365 days'
    html = None
    update = '$(domEl).empty().append("#{output}")'
    style = None

    def __init__(self, **kwargs):
        for k, v in kwargs.items():
            setattr(self, k, v)

    @property
    def refreshFrequency(self):
        return self.refresh

    @refreshFrequency.setter
    def refreshFrequency(self, value):
        self.refresh = value

    def coffee(self):
        """index.coffee source code"""
        items = [
            "command: \"%s\"" % self.command,
            "refreshFrequency: '%s'" % self.refresh
        ]
        if self.html:
            items += [_render(self.html)]
        items += ["""update: (output, domEl) ->
    %s""" % self.update]
        if self.style:
            items += [_style(self.style)]
        return "\n\n".join(items) + "\n"

    def __str__(self):
        return self.coffee()



__all__ = ['Coffee', 'Widget', 'widgets', 'kill', 'pid', 'start', 'restart']


import os
from ubersicht._coffee import Coffee
import listify
from ubersicht._widgets import Widget

WIDGETS = "%s/Library/Application Support/Übersicht/widgets" % os.environ[
    "HOME"]


def widgets():
    """return a list with widgets paths"""
    for l in os.listdir(WIDGETS):
        path = os.path.join(WIDGETS, l)
        if os.path.splitext(path)[1] == ".widget" and os.path.isdir(path):
            yield path


"""Übersicht.app process functions"""


def kill():
    """kill Übersicht.app process"""
    _pid = pid()
    if _pid:
        os.system("kill -9 %s &> /dev/null" % _pid)


def pid():
    """return Übersicht.app pid"""
    for l in os.popen("ps -ax").read().splitlines():
        if "Übersicht.app/Contents/MacOS/Übersicht" in l:
            return int(list(filter(None, l.split(" ")))[0])


def start():
    """open Übersicht.app"""
    if not pid():
        return os.system("open -a Übersicht")


def restart():
    """restart Übersicht.app"""
    kill()
    start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import shutil
from ubersicht._coffee import Coffee

WIDGETS = "%s/Library/Application Support/Übersicht/widgets" % os.environ["HOME"]


class Widget(Coffee):
    """widget generator class"""
    __readme__ = ["create", "rm"]
    name = None

    @property
    def path(self):
        """return widget path ~/Library/Application Support/Übersicht/widgets/name.widget"""
        return os.path.join(WIDGETS, "%s" % self.name)

    def create(self):
        """create widget"""
        if not os.path.exists(self.path):
            os.makedirs(self.path)
        index = os.path.join(self.path, "index.coffee")
        open(index, "w").write(self.coffee())
        return self

    def rm(self):
        """remove widget (if exists)"""
        if os.path.exists(self.path):
            shutil.rmtree(self.path)
        return self

    def __str__(self):
        return '<Widget "%s">' % self.path
